@@ -19,7 +19,7 @@ exams <- function(file, n = 1, nsamp = NULL, dir = NULL, template = "plain",
   dir_temp <- if(is.null(tdir)) tempfile() else tdir
   if(!file.exists(dir_temp) && !dir.create(dir_temp))
     stop(gettextf("Cannot create temporary work directory '%s'.", dir_temp))
-  dir_pkg <- .find.package("exams")
+  dir_pkg <- find.package("exams")
   
   ## number of available exercises in each element of 'file'
   ## and number of selected samples per element
